# Allmotion Python Serial port example

# Verified on Win 10 Pro With AllMotion USB485HS On COM3



# This example sets up serial port communication,

# asks the user for a command string, sends the command

# to the controller, reads and prints the response, and repeats.



# May need to do pip install pyserial at command prompt



import serial

import time



# Define serial ports

def serial_ports():

    ports = ['COM%s' % (i + 1) for i in range(256)]

    result = []

    for port in ports:

        try:

            s = serial.Serial(port)

            s.close()

            result.append(port)

        except (OSError, serial.SerialException):

            pass

    return result



# Set serial port and baud rate. This example uses COM3 and 9600 baud rate

if __name__ == '__main__':

    print(serial_ports())



    ser = serial.Serial(

        port='COM8',

        baudrate=9600,

        parity=serial.PARITY_NONE,

        stopbits=serial.STOPBITS_ONE,

        bytesize=serial.EIGHTBITS

    )



# Main loop to prompt user for commands and handle responses

try:

    while True:

        command = input("Enter command: ")

        if command.strip().lower() == 'exit':

            break  # Exit the loop if the user enters 'exit'

        

        # Add a prefix 'b' to encode the command as bytes

        ser.write(command.strip().encode() + b'\r\n')

        

        # Set a timeout for readline

        ser.timeout = 1.0  # 1 second timeout if no response

        

        # Reads the response on the serial port

        response = ser.readline().strip().decode('unicode-escape')

        

        # Reset timeout to None after readline

        ser.timeout = None

        

        # Remove specific characters from the response to clean up output

        response = response.translate({ord('ÿ'): None, ord('\x03'): None})

        

        # Remove leading '/0' to clean up output

        if response.startswith('/0'):

            response = response[2:]

        

        # Check if response is "@" (move response) or "'" (terminate response) and print "Sent" instead

        if response in ["@", "`"]:

            print("Sent")

        elif response:

            # Remove specified prefixes at the beginning of the response to clean up output

            prefixes_to_remove = ["`", "@"]  # These appear at the beginning of some strings

            for prefix_to_remove in prefixes_to_remove:

                if response.startswith(prefix_to_remove):

                    response = response[len(prefix_to_remove):]

                    break 

        

            print("Received response:", response)

        else:

            print("Error. No Response. Please check connections and settings or try another command.")

finally:

    ser.close()